==> rflowcyt_1.4.0.tar.gz: rflowcyt/tests/FCSmetadataclass-tests.R <==
## StopOnError or else continue through

if ("StopOnError" %in% objects()){
  if (!is.logical(StopOnError)) {
    ## default is TRUE when StopOnError is not boolean
    StopOnError <- TRUE
  }    
} else {
  ## default is to stop when there is an error 
  StopOnError <- TRUE
}


## An example FCS S4 object
if (!require(rfcdmin)){
  library(rfcdmin, lib.loc="~jyw/lib/R")
}
if (!require(rflowcyt)){
  library(rflowcyt, lib.loc="~/lib/R")
}

ErrorMsg <- NULL
FailedTestObjName <- NULL
error.printed <- names.failed <- NULL

## Create example and then test:

ex.s4 <- read.FCS(paste(system.file(package="rfcdmin"),
                        "/fcs/SEB-NP22.fcs", sep=""),
                  myFCSobj.name="ex.s4", UseS3=FALSE)
ex.s3 <- read.FCS(paste(system.file(package="rfcdmin"),
                        "/fcs/SEB-NP22.fcs", sep=""),
                  myFCSobj.name="ex.s4", UseS3=TRUE)



##  EXAMPLE FORMAT:
## create situation
## ex.s4 <- new("FCS")
## ex.s4@metadata[["$P1R"]]<-"test"

## if situation is unexpected, fail, else succeed
## if (ex.s4@metadata[["$P1R"]] != "test") {
##  stop("Test #1 failed: Can't set parameter\n")
##} else {
##  cat("Test #1 succeeded.\n")
##}


### Examples: FCSmetadata
test1 <- new("FCSmetadata")
test1@size <- 10

if (test1@size != 10){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test1 failed: Can't set size")
  FailedTestObjName <- c(FailedTestObjName, "test1")
  if (StopOnError) {
    stop("FCSmetadataclass: test1 failed: Can't set size\n")
  }
} else {
  cat("FCSmetadataclass: test1 succeeded: Able to set size.\n")
}

test2 <- new("FCSmetadata",size=4,nparam=3)
if (test2@size != 4 & test2@nparam!=3) {
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test2 failed: Can't set initialize metadata size and nparam")
  FailedTestObjName <- c(FailedTestObjName, "test2")
  if (StopOnError) {
    stop("FCSmetadataclass: test2 failed: Can't initialize metadata size and nparam\n")
  }
} else {
  cat("FCSmetadataclass: test2 succeeded: Able to initialize metadata size. and nparam\n")
}

###  FCSmetadataclass: Testing [...] extraction method

test3.1 <- ex.s4@metadata["$P1R"]
if (test3.1 != ex.s4@metadata@paramranges[1]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.1 failed: Can't extract metadata 'fcsinfo' by character name '$P1R' using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.1")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.1 failed: Can't extract metadata 'fcsinfo' by character name '$P1R' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.1 succeeded: Able to extract metadata 'fcsinfo' by character name '$P1R' using [...] \n")
}

test3.2 <- ex.s4@metadata["$MODE"]
if (unlist(test3.2) != unlist(ex.s4@metadata@mode)){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.2")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.2 succeeded: Able to extract metadata 'mode' by character name '$MODE' using [...] \n")
}

test3.3 <- ex.s4@metadata["$PnS"]
if (sum(test3.3 == ex.s4@metadata@longnames, na.rm=TRUE)!=length(test3.3[is.na(test3.3)==FALSE])){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.3 failed: Can't extract metadata 'longnames' by character name '$PnS' using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.3")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.3 failed: Can't extract metadata 'longnames' by character name '$PnS' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.3 succeeded: Able to extract metadata 'longnames' by character name '$PnS' using [...] \n")
}

test3.4 <- ex.s4@metadata[1:10]
if (sum(unlist(test3.4) == unlist(ex.s4@metadata@fcsinfo[1:10]))!=10){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.4 failed: Can't extract metadata fcsinfo by numeric index, 1:10, using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.4")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.4 failed: Can't extract metadata fcsinfo by numeric index, 1:10, using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.4 succeeded: Able to extract metadata fcsinfo by numeric index, 1:10, using [...] \n")
}


###  FCSmetadataclass: Testing [[...]] extraction method

test4.1 <- ex.s4@metadata[["$P5R"]]
if (test4.1 != ex.s4@metadata@paramranges[5]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.1 failed: Can't extract metadata 'fcsinfo' by character name '$P5R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.1")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.1 failed: Can't extract metadata 'fcsinfo' by character name '$P5R' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.1 succeeded: Able to extract metadata 'fcsinfo' by character name '$P5R' using [[...]] \n")
}

test4.2 <- ex.s4@metadata[["$MODE"]]
if (test4.2 != ex.s4@metadata@mode){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.2")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.2 succeeded: Able to extract metadata 'mode' by character name '$MODE' using [[...]] \n")
}
test4.3 <- ex.s4@metadata[["$PnN"]]
if (sum(test4.3 == ex.s4@metadata@shortnames)!=length(test4.3)){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.3 failed: Can't extract metadata 'shortnames' by character name '$PnN' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.3")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.3 failed: Can't extract metadata 'shortnames' by character name '$PnN' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.3 succeeded: Able to extract metadata 'shortnames' by character name '$PnN' using [[...]] \n")
}
test4.4 <- ex.s4@metadata[1:10]
if (sum(unlist(test4.4) == unlist(ex.s4@metadata@fcsinfo[1:10]))!=10){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.4 failed: Can't extract metadata 'fcsinfo' by numeric index 1:10 using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.4")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.4 failed: Can't extract metadata fcsinfo by numeric index 1:10 using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.4 succeeded: Able to extract metadata fcsinfo by numeric index 1:10 using [[...]] \n")
}

###FCSmetadataclass: Testing the replace methods

test5.1 <- ex.s4@metadata[["$P1R"]]
ex.s4@metadata[["$P1R"]]<-58884993002
if (test5.1 == ex.s4@metadata[["$P1R"]]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.1 failed: Can't replace metadata 'fcsinfo' by character name '$P1R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.1")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.1 failed: Can't replace metadata fcsinfo by character name '$P1R' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test5.1 succeeded: Able to replace metadata fcsinfo by character name '$P1R' using [[...]] \n")
}

ex.s4@metadata["$P1R"]<-1024
test5.2 <- 58884993002
if (test5.2 == ex.s4@metadata["$P1R"]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.2 failed: Can't replace metadata 'fcsinfo' by character name '$P1R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.2")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.2 failed: Can't replace metadata fcsinfo by character name '$P1R' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test5.2 succeeded: Able to replace metadata fcsinfo by character name '$P1R' using [...] \n")
}


orig.longnames<-ex.s4@metadata["$PnS"]
foo.names<-paste("foo", 1:ex.s4@metadata@nparam, sep="")
ex.s4@metadata["longnames"]<-foo.names

test5.3 <- ex.s4@metadata["longnames"]
if (sum(test5.3 == foo.names, na.rm=TRUE) != length(test5.3[is.na(test5.3)==FALSE])){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.3 failed: Can't replace metadata 'longnames' by character name '$PnS' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.3")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.3 failed: Can't replace metadata 'longnames' by character name '$PnS' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test5.3 succeeded: Able to replace metadata 'longnames' by character name '$PnS' using [...] \n")
}


ex.s4@metadata[["$PnS"]]<-orig.longnames
test5.4 <- ex.s4@metadata[["longnames"]]
if (sum(test5.4 == orig.longnames, na.rm=TRUE) != length(test5.4[is.na(test5.4)==FALSE])){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.4 failed: Can't replace metadata 'fcsinfo' by character name '$P5R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.4")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.4 failed: Can't replace metadata 'longnames' by character name '$PnS' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test5.4 succeeded: Able to replace metadata 'longnames' by character name '$PnS' using [[...]] \n")
}


if (is.null(FailedTestObjName) & is.null(ErrorMsg)){
  names.failed <- "None; all FCSmetadataclass tests were successful."
  error.printed <- "None; all FCSmetadataclass tests were successful."
} else {
  names.failed <- matrix(FailedTestObjName, ncol=1)
  error.printed <- ErrorMsg
}
cat("These are the following test objects that have failed: \n\n")
print(names.failed)
cat("\n\n\n")
cat("These are the corresponding Error Messages: \n\n")
print(error.printed)

==> rflowcyt_1.20.0.tar.gz: rflowcyt/tests/FCSmetadataclass-tests.R <==
## StopOnError or else continue through

if ("StopOnError" %in% objects()){
  if (!is.logical(StopOnError)) {
    ## default is TRUE when StopOnError is not boolean
    StopOnError <- TRUE
  }    
} else {
  ## default is to stop when there is an error 
  StopOnError <- TRUE
}


## An example FCS S4 object
if (!require(rfcdmin)){
  library(rfcdmin, lib.loc="~jyw/lib/R")
}
if (!require(rflowcyt)){
  library(rflowcyt, lib.loc="~/lib/R")
}

ErrorMsg <- NULL
FailedTestObjName <- NULL
error.printed <- names.failed <- NULL

## Create example and then test:

ex.s4 <- read.FCS(paste(system.file(package="rfcdmin"),
                        "/fcs/SEB-NP22.fcs", sep=""),
                  FCSobj.name="ex.s4", UseS3=FALSE)
ex.s3 <- read.FCS(paste(system.file(package="rfcdmin"),
                        "/fcs/SEB-NP22.fcs", sep=""),
                  FCSobj.name="ex.s4", UseS3=TRUE)



##  EXAMPLE FORMAT:
## create situation
## ex.s4 <- new("FCS")
## ex.s4@metadata[["$P1R"]]<-"test"

## if situation is unexpected, fail, else succeed
## if (ex.s4@metadata[["$P1R"]] != "test") {
##  stop("Test #1 failed: Can't set parameter\n")
##} else {
##  cat("Test #1 succeeded.\n")
##}


### Examples: FCSmetadata
test1 <- new("FCSmetadata")
test1@size <- 10

if (test1@size != 10){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test1 failed: Can't set size")
  FailedTestObjName <- c(FailedTestObjName, "test1")
  if (StopOnError) {
    stop("FCSmetadataclass: test1 failed: Can't set size\n")
  }
} else {
  cat("FCSmetadataclass: test1 succeeded: Able to set size.\n")
}

test2 <- new("FCSmetadata",size=4,nparam=3)
if (test2@size != 4 & test2@nparam!=3) {
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test2 failed: Can't set initialize metadata size and nparam")
  FailedTestObjName <- c(FailedTestObjName, "test2")
  if (StopOnError) {
    stop("FCSmetadataclass: test2 failed: Can't initialize metadata size and nparam\n")
  }
} else {
  cat("FCSmetadataclass: test2 succeeded: Able to initialize metadata size. and nparam\n")
}

###  FCSmetadataclass: Testing [...] extraction method

test3.1 <- ex.s4@metadata["$P1R"]
if (test3.1 != ex.s4@metadata@paramranges[1]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.1 failed: Can't extract metadata 'fcsinfo' by character name '$P1R' using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.1")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.1 failed: Can't extract metadata 'fcsinfo' by character name '$P1R' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.1 succeeded: Able to extract metadata 'fcsinfo' by character name '$P1R' using [...] \n")
}

test3.2 <- ex.s4@metadata["$MODE"]
if (unlist(test3.2) != unlist(ex.s4@metadata@mode)){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.2")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.2 succeeded: Able to extract metadata 'mode' by character name '$MODE' using [...] \n")
}

test3.3 <- ex.s4@metadata["$PnS"]
if (sum(test3.3 == ex.s4@metadata@longnames, na.rm=TRUE)!=length(test3.3[is.na(test3.3)==FALSE])){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.3 failed: Can't extract metadata 'longnames' by character name '$PnS' using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.3")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.3 failed: Can't extract metadata 'longnames' by character name '$PnS' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.3 succeeded: Able to extract metadata 'longnames' by character name '$PnS' using [...] \n")
}

test3.4 <- ex.s4@metadata[1:10]
if (sum(unlist(test3.4) == unlist(ex.s4@metadata@fcsinfo[1:10]))!=10){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test3.4 failed: Can't extract metadata fcsinfo by numeric index, 1:10, using [...]")
  FailedTestObjName <- c(FailedTestObjName, "test3.4")
  if (StopOnError) {
    stop("FCSmetadataclass: test3.4 failed: Can't extract metadata fcsinfo by numeric index, 1:10, using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test3.4 succeeded: Able to extract metadata fcsinfo by numeric index, 1:10, using [...] \n")
}


###  FCSmetadataclass: Testing [[...]] extraction method

test4.1 <- ex.s4@metadata[["$P5R"]]
if (test4.1 != ex.s4@metadata@paramranges[5]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.1 failed: Can't extract metadata 'fcsinfo' by character name '$P5R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.1")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.1 failed: Can't extract metadata 'fcsinfo' by character name '$P5R' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.1 succeeded: Able to extract metadata 'fcsinfo' by character name '$P5R' using [[...]] \n")
}

test4.2 <- ex.s4@metadata[["$MODE"]]
if (test4.2 != ex.s4@metadata@mode){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.2")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.2 failed: Can't extract metadata 'mode' by character name '$MODE' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.2 succeeded: Able to extract metadata 'mode' by character name '$MODE' using [[...]] \n")
}
test4.3 <- ex.s4@metadata[["$PnN"]]
if (sum(test4.3 == ex.s4@metadata@shortnames)!=length(test4.3)){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.3 failed: Can't extract metadata 'shortnames' by character name '$PnN' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.3")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.3 failed: Can't extract metadata 'shortnames' by character name '$PnN' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.3 succeeded: Able to extract metadata 'shortnames' by character name '$PnN' using [[...]] \n")
}
test4.4 <- ex.s4@metadata[1:10]
if (sum(unlist(test4.4) == unlist(ex.s4@metadata@fcsinfo[1:10]))!=10){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test4.4 failed: Can't extract metadata 'fcsinfo' by numeric index 1:10 using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test4.4")
  if (StopOnError) {
    stop("FCSmetadataclass: test4.4 failed: Can't extract metadata fcsinfo by numeric index 1:10 using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test4.4 succeeded: Able to extract metadata fcsinfo by numeric index 1:10 using [[...]] \n")
}

###FCSmetadataclass: Testing the replace methods

test5.1 <- ex.s4@metadata[["$P1R"]]
ex.s4@metadata[["$P1R"]]<-58884993002
if (test5.1 == ex.s4@metadata[["$P1R"]]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.1 failed: Can't replace metadata 'fcsinfo' by character name '$P1R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.1")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.1 failed: Can't replace metadata fcsinfo by character name '$P1R' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test5.1 succeeded: Able to replace metadata fcsinfo by character name '$P1R' using [[...]] \n")
}

ex.s4@metadata["$P1R"]<-1024
test5.2 <- 58884993002
if (test5.2 == ex.s4@metadata["$P1R"]){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.2 failed: Can't replace metadata 'fcsinfo' by character name '$P1R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.2")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.2 failed: Can't replace metadata fcsinfo by character name '$P1R' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test5.2 succeeded: Able to replace metadata fcsinfo by character name '$P1R' using [...] \n")
}


orig.longnames<-ex.s4@metadata["$PnS"]
foo.names<-paste("foo", 1:ex.s4@metadata@nparam, sep="")
ex.s4@metadata["longnames"]<-foo.names

test5.3 <- ex.s4@metadata["longnames"]
if (sum(test5.3 == foo.names, na.rm=TRUE) != length(test5.3[is.na(test5.3)==FALSE])){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.3 failed: Can't replace metadata 'longnames' by character name '$PnS' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.3")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.3 failed: Can't replace metadata 'longnames' by character name '$PnS' using [...] \n")
  }
} else {
  cat("FCSmetadataclass: test5.3 succeeded: Able to replace metadata 'longnames' by character name '$PnS' using [...] \n")
}


ex.s4@metadata[["$PnS"]]<-orig.longnames
test5.4 <- ex.s4@metadata[["longnames"]]
if (sum(test5.4 == orig.longnames, na.rm=TRUE) != length(test5.4[is.na(test5.4)==FALSE])){
  ErrorMsg <- c(ErrorMsg, "FCSmetadataclass: test5.4 failed: Can't replace metadata 'fcsinfo' by character name '$P5R' using [[...]]")
  FailedTestObjName <- c(FailedTestObjName, "test5.4")
  if (StopOnError) {
    stop("FCSmetadataclass: test5.4 failed: Can't replace metadata 'longnames' by character name '$PnS' using [[...]] \n")
  }
} else {
  cat("FCSmetadataclass: test5.4 succeeded: Able to replace metadata 'longnames' by character name '$PnS' using [[...]] \n")
}


if (is.null(FailedTestObjName) & is.null(ErrorMsg)){
  names.failed <- "None; all FCSmetadataclass tests were successful."
  error.printed <- "None; all FCSmetadataclass tests were successful."
} else {
  names.failed <- matrix(FailedTestObjName, ncol=1)
  error.printed <- ErrorMsg
}
cat("These are the following test objects that have failed: \n\n")
print(names.failed)
cat("\n\n\n")
cat("These are the corresponding Error Messages: \n\n")
print(error.printed)
